﻿using System;
using System.Data;
using System.Diagnostics;
using System.Windows.Forms;
using C1.Win.C1FlexGrid;

namespace FlexGrid.FixedCheckBox
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            //enabling OwnerDraw
            c1FlexGrid1.DrawMode = DrawModeEnum.OwnerDraw;
            c1FlexGrid1.OwnerDrawCell += C1FlexGrid1_OwnerDrawCell;

            //Setting sample data
            c1FlexGrid1.DataSource = GetDataTable();

            //Handle AfterEdit event to update the fixed column
            c1FlexGrid1.AfterEdit += C1FlexGrid1_AfterEdit;

            //Set a text-type format to the checkbox column
            c1FlexGrid1.Cols["CheckMark"].Format = "Yes;No";
        }

        private void C1FlexGrid1_AfterEdit(object sender, RowColEventArgs e)
        {
            //If color column is edited, invalidate the fixed column to update the checkbox
            if (c1FlexGrid1.Cols[e.Col].Name.Equals("Color"))
                c1FlexGrid1.Invalidate(e.Row, 0);
        }

        private void C1FlexGrid1_OwnerDrawCell(object sender, OwnerDrawCellEventArgs e)
        {
            //Return if event is only fired for measuring the cell
            if (e.Measuring) return;

            //if data row and fixed column
            if (e.Row >= c1FlexGrid1.Rows.Fixed && e.Col == c1FlexGrid1.Cols.IndexOf("CheckMark"))
            {
                //draw only background, border and not the default checkbox image
                e.DrawCell(DrawCellFlags.Border | DrawCellFlags.Background);

                //Set text to empty and draw custom image
                e.Text = string.Empty;
                e.Image = c1FlexGrid1.Glyphs[GlyphEnum.Checked];
                e.DrawCell(DrawCellFlags.Content);

                //indicate that the drawing for this cell is handled
                e.Handled = true;
            }
        }

        /// <summary>
        /// Sample DataTable for the grid
        /// </summary>
        private DataTable GetDataTable()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("ID", typeof(int));
            dt.Columns.Add("CheckMark", typeof(bool));
            dt.Columns.Add("Color", typeof(CustomColor));
            for (int i = 1; i <= 20; i++)
            {
                dt.Rows.Add(i, i % 2 == 0, i % 2 == 0 ? CustomColor.Red : CustomColor.Blue);
            }
            return dt;
        }
    }

    internal enum CustomColor
    {
        Red,
        Blue
    }
}
